@@ -3,15 +3,13 @@ use std::io;
 use std::path::{Component, Path, PathBuf};
 use std::time::SystemTime;
 
-use actix_web::dev::ServiceResponse;
-use actix_web::web::Query;
-use actix_web::{HttpMessage, HttpRequest, HttpResponse};
+use actix_web::{dev::ServiceResponse, web::Query, HttpMessage, HttpRequest, HttpResponse};
 use bytesize::ByteSize;
 use comrak::{markdown_to_html, ComrakOptions};
 use percent_encoding::{percent_decode_str, utf8_percent_encode};
 use regex::Regex;
 use serde::Deserialize;
-use strum_macros::{Display, EnumString};
+use strum::{Display, EnumString};
 
 use crate::archive::ArchiveMethod;
 use crate::auth::CurrentUser;
@@ -165,12 +163,12 @@ pub fn directory_listing(
 
     let base = Path::new(serve_path);
     let random_route_abs = format!("/{}", conf.route_prefix);
-    let abs_url = format!(
-        "{}://{}{}",
-        req.connection_info().scheme(),
-        req.connection_info().host(),
-        req.uri()
-    );
+    let abs_uri = http::Uri::builder()
+        .scheme(req.connection_info().scheme())
+        .authority(req.connection_info().host())
+        .path_and_query(req.uri().to_string())
+        .build()
+        .unwrap();
     let is_root = base.parent().is_none() || Path::new(&req.path()) == Path::new(&random_route_abs);
 
     let encoded_dir = match base.strip_prefix(random_route_abs) {
@@ -244,7 +242,7 @@ pub fn directory_listing(
                 .and_then(|path| std::fs::read_link(path).ok())
                 .map(|path| path.to_string_lossy().into_owned());
             let file_url = base
-                .join(&utf8_percent_encode(&file_name, PATH_SEGMENT).to_string())
+                .join(utf8_percent_encode(&file_name, PATH_SEGMENT).to_string())
                 .to_string_lossy()
                 .to_string();
 
@@ -370,7 +368,7 @@ pub fn directory_listing(
                 .append_header(("Content-Transfer-Encoding", "binary"))
                 .append_header((
                     "Content-Disposition",
-                    format!("attachment; filename={:?}", file_name),
+                    format!("attachment; filename={file_name:?}"),
                 ))
                 .body(actix_web::body::BodyStream::new(rx)),
         ))
@@ -381,7 +379,7 @@ pub fn directory_listing(
                 renderer::page(
                     entries,
                     readme,
-                    abs_url,
+                    &abs_uri,
                     is_root,
                     query_params,
                     &breadcrumbs,
